==> haskell-lifted-base-0.2.3.12-424.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-base
version:              0.2.3.12
visibility:           public
id:                   lifted-base-0.2.3.12-BlE7lcjJgycKqbOSX0EJAx
key:                  lifted-base-0.2.3.12-BlE7lcjJgycKqbOSX0EJAx
license:              BSD-3-Clause
copyright:            (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk, Anders Kaseorg
homepage:             https://github.com/basvandijk/lifted-base
synopsis:             lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.

    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.

category:             Control
abi:                  1ba5d80c16ab5a6bd8dfe90df0c2c7a0
exposed:              True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-base
hs-libraries:         HSlifted-base-0.2.3.12-BlE7lcjJgycKqbOSX0EJAx
includes:             inlinable.h
depends:
    base-4.17.2.1 monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs
    transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA

haddock-interfaces:   /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html:         /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-base-0.2.3.12-436.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-base
version:              0.2.3.12
visibility:           public
id:                   lifted-base-0.2.3.12-IVPotbRKgpV4XWohxm9AEV
key:                  lifted-base-0.2.3.12-IVPotbRKgpV4XWohxm9AEV
license:              BSD-3-Clause
copyright:            (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk, Anders Kaseorg
homepage:             https://github.com/basvandijk/lifted-base
synopsis:             lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.

    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.

category:             Control
abi:                  e8c7ef57c15855d2137d1e001272a685
exposed:              True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/lifted-base-0.2.3.12
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/lifted-base-0.2.3.12
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-base
hs-libraries:         HSlifted-base-0.2.3.12-IVPotbRKgpV4XWohxm9AEV
includes:             inlinable.h
depends:
    base-4.18.3.0 monad-control-1.0.3.1-FK5MwN7CLMeDFbgWPeqycv
    transformers-base-0.4.6-KecQozQ2bJs3HLDcaEYSEy

haddock-interfaces:   /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html:         /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
